[Checkins] SVN: zope.schema/trunk/ prepare for 3.3.0 release

Baiju M baiju.m.mail at gmail.com
Thu Mar 15 00:02:05 EDT 2007


Log message for revision 73181:
  prepare for 3.3.0 release
  

Changed:
  _U  zope.schema/trunk/
  D   zope.schema/trunk/CHANGES.txt
  U   zope.schema/trunk/README.txt
  _U  zope.schema/trunk/bootstrap.py
  UU  zope.schema/trunk/setup.py
  _U  zope.schema/trunk/src/zope/

-=-

Property changes on: zope.schema/trunk
___________________________________________________________________
Name: svn:ignore
   - bin
build
dist
lib
setup.cfg

   + bin
build
dist
lib
develop-eggs
eggs
parts
.installed.cfg


Deleted: zope.schema/trunk/CHANGES.txt
===================================================================
--- zope.schema/trunk/CHANGES.txt	2007-03-15 02:33:28 UTC (rev 73180)
+++ zope.schema/trunk/CHANGES.txt	2007-03-15 04:02:05 UTC (rev 73181)
@@ -1,37 +0,0 @@
-zope.schema Package Changelog
-=============================
-
-zope.schema version 3.2.1 (2006/03/26)
---------------------------------------
-
-Corresponds to the verison of the zope.schema package shipped as part of
-the Zope 3.2.1 release.
-
-Fixed missing import of 'VocabularyRegistryError'.  See
-http://www.zope.org/Collectors/Zope3-dev/544 .
-
-zope.schema version 3.2.0 (2006/01/05)
---------------------------------------
-
-Corresponds to the verison of the zope.schema package shipped as part of
-the Zope 3.2.0 release.
-
-Added "iterable" sources to replace vocabularies, which are now deprecated
-and scheduled for removal in Zope 3.3.
-
-zope.schema version 3.1.0 (2005/10/03)
---------------------------------------
-
-Corresponds to the verison of the zope.schema package shipped as part of
-the Zope 3.1.0 release.
-
-Allowed 'Choice' fields to take either a 'vocabulary' or a 'source'
-argument (sources are a simpler implementation).
-
-Added 'TimeDelta' and 'ASCIILine' field types.
-
-zope.schema version 3.0.0 (2004/11/07)
---------------------------------------
-
-Corresponds to the verison of the zope.schema package shipped as part of
-the Zope X3.0.0 release.

Modified: zope.schema/trunk/README.txt
===================================================================
--- zope.schema/trunk/README.txt	2007-03-15 02:33:28 UTC (rev 73180)
+++ zope.schema/trunk/README.txt	2007-03-15 04:02:05 UTC (rev 73181)
@@ -1,15 +1,63 @@
-zope.schema Package Readme
-==========================
+***********
+zope.schema
+***********
 
-Overview
---------
+Schemas extend the notion of interfaces to detailed descriptions of
+Attributes (but not methods).  Every schema is an interface and
+specifies the public fields of an object.  A *field* roughly
+corresponds to an attribute of a python object.  But a Field provides
+space for at least a title and a description.  It can also constrain
+its value and provide a validation method.  Besides you can optionally
+specify characteristics such as its value being read-only or not
+required.
 
-Schemas extend the notion of interfaces to detailed descriptions of Attributes
-(but not methods). Every schema is an interface and specifies the public
-fields of an object. A *field* roughly corresponds to an attribute of a
-python object. But a Field provides space for at least a title and a
-description. It can also constrain its value and provide a validation method.
-Besides you can optionally specify characteristics such as its value being
-read-only or not required.
+See 'src/zope/schema/README.txt' for more information.
 
-See 'src/zope/schema/README.txt' for more information.
+Releases
+********
+
+==================
+3.3.0 (2007/03/15)
+==================
+
+Corresponds to the verison of the zope.schema package shipped as part of
+the Zope 3.3.0 release.
+
+==================
+3.2.1 (2006/03/26)
+==================
+
+Corresponds to the verison of the zope.schema package shipped as part of
+the Zope 3.2.1 release.
+
+Fixed missing import of 'VocabularyRegistryError'.  See
+http://www.zope.org/Collectors/Zope3-dev/544 .
+
+==================
+3.2.0 (2006/01/05)
+==================
+
+Corresponds to the verison of the zope.schema package shipped as part of
+the Zope 3.2.0 release.
+
+Added "iterable" sources to replace vocabularies, which are now deprecated
+and scheduled for removal in Zope 3.3.
+
+==================
+3.1.0 (2005/10/03)
+==================
+
+Corresponds to the verison of the zope.schema package shipped as part of
+the Zope 3.1.0 release.
+
+Allowed 'Choice' fields to take either a 'vocabulary' or a 'source'
+argument (sources are a simpler implementation).
+
+Added 'TimeDelta' and 'ASCIILine' field types.
+
+==================
+3.0.0 (2004/11/07)
+==================
+
+Corresponds to the verison of the zope.schema package shipped as part of
+the Zope X3.0.0 release.


Property changes on: zope.schema/trunk/bootstrap.py
___________________________________________________________________
Name: svn:keywords
   + Id

Modified: zope.schema/trunk/setup.py
===================================================================
--- zope.schema/trunk/setup.py	2007-03-15 02:33:28 UTC (rev 73180)
+++ zope.schema/trunk/setup.py	2007-03-15 04:02:05 UTC (rev 73181)
@@ -11,7 +11,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """Setup for zope.i18nmessageid package
 
 $Id$
 """
@@ -20,14 +20,28 @@
 
 from setuptools import setup, find_packages
 
+def read(*rnames):
+    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()
+
 setup(name='zope.schema',
-      version='3.3dev',
+      version='3.3.0',
       url='http://svn.zope.org/zope.schema',
       license='ZPL 2.1',
       description='Zope3 Data Schemas',
       author='Zope Corporation and Contributors',
       author_email='zope3-dev at zope.org',
-      
+      long_description=(
+        read('README.txt')
+        + '\n' +
+        'Detailed Documentation\n'
+        '**********************\n'
+        + '\n' +
+        read('src', 'zope', 'schema', 'README.txt')
+        + '\n' +
+        'Download\n'
+        '**********************\n'
+        ),
+
       packages=find_packages('src'),
       package_dir = {'': 'src'},
 
@@ -11,7 +11,7 @@
 #
 ##############################################################################
-"""Setup for zope.i18nmessageid package
+"""Setup for zope.schema package
 
 $Id$


Property changes on: zope.schema/trunk/setup.py
___________________________________________________________________
Name: svn:keywords
   + Id


Property changes on: zope.schema/trunk/src/zope
___________________________________________________________________
Name: svn:externals
   - schema svn://svn.zope.org/repos/main/Zope3/trunk/src/zope/schema

   + schema svn://svn.zope.org/repos/main/Zope3/tags/3.3.0/src/zope/schema




More information about the Checkins mailing list